import { 
  select, 
  csv, 
  scaleTime, 
  extent, 
  scaleLinear, 
  axisLeft,
  axisBottom, 
  format,
  line,
  curveBasis
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const render = data => {
  const xValue = d => d.timestamp;
  const xAxisTitle = 'Time';
  const yValue = d => d.temperature;
  const yAxisTitle = 'Temperature (C)';
  const plotTitle = 'One Week of Temperature in San Francisco'
  const margin = { top: 40, bottom: 80, left: 150, right: 50};
  const circleRadius = 6;
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
/* linear scale basically maps your data to pixels or, domain to range, allowing quantitative data to scale to pixels on the screen*/  
// extent pulls min and max values in an array  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();

  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);

// creating the y axis  
  const yAxis = axisLeft(yScale)
  	.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.tick line, .domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axisLabel')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisTitle);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(${0}, ${innerHeight})`);
  
  xAxisG.selectAll('.tick line, .domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axisLabel')
  	.attr('y',  65)
  	.attr('x', innerWidth / 2)
  	.text(xAxisTitle);

// adding a title to the chart  
  g.append('text')
  	.text(plotTitle)
  	.attr('x', 70)
  	.attr('y', -7);

  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);

  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', lineGenerator(data));
};

// bandwidth function is the auto computed width of a single bar

// load data and then for each row convert it to a float and multiply by thousands since data source was given in thousands to get full population

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv').then(data => {
  data.forEach(d => {
  	d.temperature = +d.temperature;
    d.timestamp = new Date(d.timestamp);
    });
  render(data);
});

